@@ -3,7 +3,7 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2022 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -83,7 +83,8 @@ dl_import("from . import libgraph_tool_layout")
 __all__ = ["graph_draw", "graphviz_draw", "fruchterman_reingold_layout",
            "arf_layout", "sfdp_layout", "planar_layout", "random_layout",
            "radial_tree_layout", "cairo_draw", "prop_to_size",
-           "get_hierarchy_control_points", "default_cm", "default_clrs"]
+           "get_hierarchy_control_points", "default_cm", "default_cm_bin",
+           "default_clrs"]
 
 
 def random_layout(g, shape=None, pos=None, dim=2):
@@ -846,7 +847,8 @@ def prop_to_size(prop, mi=0, ma=5, log=False, power=0.5):
 
 try:
     from . cairo_draw import graph_draw, cairo_draw, \
-        get_hierarchy_control_points, default_cm, default_clrs, draw_hierarchy
+        get_hierarchy_control_points, default_cm,  default_cm_bin, \
+        default_clrs, draw_hierarchy
     __all__ += ["draw_hierarchy"]
 except ImportError:
     pass
