@@ -3,7 +3,7 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2022 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -706,9 +706,8 @@ class DrawBlockState(ABC):
         gradient = group_vector_property([gradient])
         b = self.g.own_property(self.b)
         return graph_tool.draw.graph_draw(self.g,
-                                          vertex_fill_color=kwargs.get("vertex_fill_color", b),
-                                          vertex_color=kwargs.get("vertex_color", b),
-                                          edge_gradient=kwargs.get("edge_gradient", gradient),
-                                          **dmask(kwargs, ["vertex_fill_color",
-                                                           "vertex_color",
-                                                           "edge_gradient"]))
+                                          vertex_fill_color=kwargs.pop("vertex_fill_color", b),
+                                          vertex_color=kwargs.pop("vertex_color", b),
+                                          edge_gradient=kwargs.pop("edge_gradient", gradient),
+                                          vcmap=kwargs.pop("vcmap", graph_tool.draw.default_cm),
+                                          **kwargs)
