@@ -3,7 +3,7 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2022 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -35,7 +35,7 @@ class UncertainBaseState(object):
     r"""Base state for uncertain network inference."""
 
     def __init__(self, g, nested=True, state_args={}, bstate=None,
-                 self_loops=False, init_empty=False):
+                 self_loops=False, init_empty=False, max_w=1 << 16):
 
         self.g = g
 
@@ -108,6 +108,8 @@ class UncertainBaseState(object):
         self.slist = Vector_size_t(init=edges[:,0])
         self.tlist = Vector_size_t(init=edges[:,1])
 
+        self.max_w = max_w
+
         init_q_cache()
 
     def __getstate__(self):
@@ -166,7 +168,7 @@ class UncertainBaseState(object):
         verbose = kwargs.get("verbose", False)
         slist = self.slist
         tlist = self.tlist
-        entropy_args = kwargs.get("entropy_args", {})
+        entropy_args = kwargs["entropy_args"] = kwargs.get("entropy_args", {}).copy()
         entropy_args = self._get_entropy_args(entropy_args)
         kwargs.get("entropy_args", {}).pop("latent_edges", None)
         kwargs.get("entropy_args", {}).pop("density", None)
@@ -202,7 +204,6 @@ class UncertainBaseState(object):
         :meth:`~graph_tool.inference.BlockState.multiflip_mcmc_sweep`,
         if ``multiflip=True``.
         """
-
         if multiflip:
             return self._algo_sweep(lambda s, **kw: s.multiflip_mcmc_sweep(**kw),
                                     r=r, **kwargs)
@@ -445,7 +446,8 @@ class LatentMultigraphBlockState(UncertainBaseState):
     References
     ----------
     .. [peixoto-latent-2020] Tiago P. Peixoto, "Latent Poisson models for
-       networks with heterogeneous density", :doi:`10.1103/PhysRevE.102.012309`, :arxiv:`2002.07803`
+       networks with heterogeneous density", Phys. Rev. E 102 012309 (2020)
+       :doi:`10.1103/PhysRevE.102.012309`, :arxiv:`2002.07803`
     """
 
     def __init__(self, g, aE=numpy.nan, nested=True, state_args={},
@@ -512,6 +514,16 @@ class MeasuredBlockState(UncertainBaseState):
         Total number of measurements for each non-edge.
     x_default : ``int`` (optional, default: ``0``)
         Total number of positive measurements for each non-edge.
+    lp : ``float`` (optional, default: ``NaN``)
+        Log-probability of missing edges (false negatives). If given as ``NaN``,
+        it is assumed this is an unknown sampled from a Beta distribution, with
+        hyperparameters given by ``fn_params`.  Otherwise the  values of
+        ``fn_params`` are ignored.
+    lq : ``float`` (optional, default: ``NaN``)
+        Log-probability of spurious edges (false positives). If given as
+        ``NaN``, it is assumed this is an unknown sampled from a Beta
+        distribution, with hyperparameters given by ``fp_params`. Otherwise the
+        values of ``fp_params`` are ignored.
     fn_params : ``dict`` (optional, default: ``dict(alpha=1, beta=1)``)
         Beta distribution hyperparameters for the probability of missing
         edges (false negatives).
@@ -529,7 +541,7 @@ class MeasuredBlockState(UncertainBaseState):
         Arguments to be passed to
         :class:`~graph_tool.inference.NestedBlockState` or
         :class:`~graph_tool.inference.BlockState`.
-    bstate : :class:`~graph_tool.inference.NestedBlockState` or :class:`~graph_tool.inference.BlockState`  (optional, default: ``None``)
+    bstate : :class:`~graph_tool.inference.NestedBlockState` or :class:`~graph_tool.inference.BlockState` (optional, default: ``None``)
         If passed, this will be used to initialize the block state
         directly.
     self_loops : bool (optional, default: ``False``)
@@ -541,12 +553,13 @@ class MeasuredBlockState(UncertainBaseState):
     .. [peixoto-reconstructing-2018] Tiago P. Peixoto, "Reconstructing
        networks with unknown and heterogeneous errors", Phys. Rev. X 8
        041011 (2018). :doi:`10.1103/PhysRevX.8.041011`, :arxiv:`1806.07956`
+
     """
 
-    def __init__(self, g, n, x, n_default=1, x_default=0,
-                 fn_params=dict(alpha=1, beta=1), fp_params=dict(mu=1, nu=1),
-                 aE=numpy.nan, nested=True, state_args={}, bstate=None,
-                 self_loops=False, **kwargs):
+    def __init__(self, g, n, x, n_default=1, x_default=0, lp=numpy.nan,
+                 lq=numpy.nan, fn_params=dict(alpha=1, beta=1),
+                 fp_params=dict(mu=1, nu=1), aE=numpy.nan, nested=True,
+                 state_args={}, bstate=None, self_loops=False, **kwargs):
 
         super().__init__(g, nested=nested, state_args=state_args, bstate=bstate,
                          **kwargs)
@@ -565,6 +578,8 @@ class MeasuredBlockState(UncertainBaseState):
         self.beta = fn_params.get("beta", 1)
         self.mu = fp_params.get("mu", 1)
         self.nu = fp_params.get("nu", 1)
+        self.lp = lp
+        self.lq = lq
 
         self._state = libinference.make_measured_state(self.bstate._state,
                                                        self)
@@ -574,7 +589,8 @@ class MeasuredBlockState(UncertainBaseState):
         return dict(state, n=self.n, x=self.x, n_default=self.n_default,
                     x_default=self.x_default,
                     fn_params=dict(alpha=self.alpha, beta=self.beta),
-                    fp_params=dict(mu=self.mu, nu=self.nu), aE=self.aE)
+                    fp_params=dict(mu=self.mu, nu=self.nu), lp=self.lp,
+                    lq=self.lq, aE=self.aE)
 
     def copy(self, **kwargs):
         """Return a copy of the state."""
